==> mailtrap-0.1.4.tar.gz: mailtrap-0.1.4/setup.py <==
import os
import subprocess

from setuptools import setup
from setuptools.command.build_py import build_py


class build_py_with_assets(build_py):
    def run(self):
        if not self.dry_run:
            self._build_assets()
        build_py.run(self)

    def _build_assets(self):
        asset_dir = 'mailtrap/static/assets'
        # Lame check if we have prebuilt assets. If we do so we are probably installing from a pypi package which
        # means that webassets might not be installed yet and thus we cannot build the assets now...
        if os.path.exists(asset_dir) and os.listdir(asset_dir):
            return
        args = ['webassets', '-m', 'mailtrap.web', 'build']
        with open(os.devnull, 'w') as devnull:
            subprocess.check_call(args, stderr=devnull)
            subprocess.check_call(args + ['--production'], stderr=devnull)


with open('requirements.txt') as f:
    requirements = f.read().splitlines()
with open('README.md') as f:
    readme = f.read()

setup(
    name='mailtrap',
    version='0.1.4',
    description='An SMTP server that makes all received mails accessible via a web interface and REST API.',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/msztolcman/mailtrap',
    download_url='https://github.com/msztolcman/mailtrap',
    author='Marcin Sztolcman',
    author_email='marcin@urzenia.net',
    license='MIT',
    zip_safe=False,
    include_package_data=True,
    packages=('mailtrap', 'mailtrap_runner'),
    entry_points={
        'console_scripts': [
            'mailtrap = mailtrap_runner.__main__:main',
        ],
    },
    install_requires=requirements,
    cmdclass={'build_py': build_py_with_assets},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Environment :: No Input/Output (Daemon)',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Topic :: Communications :: Email',
        'Topic :: Software Development',
        'Topic :: System :: Networking',
        'Topic :: Utilities'
    ]
)

==> mailtrap-1.0.0.tar.gz: mailtrap-1.0.0/setup.py <==
import os
import subprocess
import shutil

from setuptools import setup, find_packages
from setuptools.command.build_py import build_py

requirements = [
    'aiohttp',
    'aiohttp-basicauth',
    'aiohttp-jinja2',
    'aiosmtpd',
    'aiosqlite',
    'beautifulsoup4',
    'cssmin',
    'html5lib',
    'lockfile',
    'passlib',
    'python-daemon',
    'pytz',
    'pyscss',
    'structlog',
    'webassets',
]


class BuildPyWithAssets(build_py):
    def run(self):
        if not self.dry_run:
            self._build_assets()
        build_py.run(self)

    def _build_assets(self):
        asset_dir = 'mailtrap/static/assets'
        # Lame check if we have prebuilt assets. If we do so we are probably installing from a pypi package which
        # means that webassets might not be installed yet and thus we cannot build the assets now...
        if os.path.exists(asset_dir) and os.listdir(asset_dir):
            return

        webassets = shutil.which('webassets')
        if not webassets:
            print("Cannot find webassets. Please execute manually: /path/to/webassets -m mailtrap.build_assets build'")
            return

        args = ['webassets', '-m', 'mailtrap.build_assets', 'build']
        with open(os.devnull, 'w') as devnull:
            subprocess.check_call(args, stderr=devnull)
            subprocess.check_call(args + ['--production'], stderr=devnull)


with open('README.md') as f:
    readme = f.read()

setup(
    name='mailtrap',
    version='1.0.0',
    description='An SMTP server that makes all received mails accessible via a web interface and REST API.',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/msztolcman/mailtrap',
    project_urls={
        'GitHub: issues': 'https://github.com/msztolcman/mailtrap/issues',
        'GitHub: repo': 'https://github.com/msztolcman/mailtrap',
    },
    download_url='https://github.com/msztolcman/mailtrap',
    author='Marcin Sztolcman',
    author_email='marcin@urzenia.net',
    license='MIT',
    zip_safe=False,
    include_package_data=True,
    packages=find_packages(),
    python_requires='>=3.7',
    entry_points={
        'console_scripts': [
            'mailtrap = mailtrap.cli:main',
        ],
    },
    install_requires=requirements,
    cmdclass={'build_py': BuildPyWithAssets},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Environment :: No Input/Output (Daemon)',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Operating System :: MacOS :: MacOS X',
        'Topic :: Communications :: Email',
        'Topic :: Software Development',
        'Topic :: System :: Networking',
        'Topic :: Utilities',
        'Framework :: AsyncIO',
    ]
)
